@@ -106,6 +106,19 @@ def set_ticks(axs: Axes, *, major: Optional[str] = None, minor: Optional[str] =
     "y" in minor and do_setting(axs.yaxis, "minor")
 
 
+def set_same_ticks(axs: Axes):
+    """Change locator so that both axis use the same interval, while keeping current autorange
+
+    :param Axes axs: Axes object to manipulate
+    """
+    xvals = axs.get_xaxis().get_major_locator()()
+    yvals = axs.get_yaxis().get_major_locator()()
+    spacing = max(xvals[1] - xvals[0], yvals[1] - yvals[0])
+    from matplotlib.ticker import MultipleLocator
+    axs.get_xaxis().set_major_locator(MultipleLocator(spacing))
+    axs.get_yaxis().set_major_locator(MultipleLocator(spacing))
+
+
 def set_grid(axs: Axes):
     """Apply default grid settings to Axes
 
@@ -126,6 +139,20 @@ def get_object_facecolor(obj):
     return None
 
 
+def _is_jupyter():
+    # https://stackoverflow.com/q/15411967
+    try:
+        shell = get_ipython().__class__.__name__
+        if shell == 'ZMQInteractiveShell':
+            return True   # Jupyter notebook or qtconsole
+        elif shell == 'TerminalInteractiveShell':
+            return False  # Terminal running IPython
+        else:
+            return False  # Other type (?)
+    except NameError:
+        return False      # Probably standard Python interpreter
+
+
 def finalize(fig: Figure, filename: Optional[str] = None):
     """Show and/or save the figure, and close(dispose) it afterwards.
 
@@ -139,7 +166,11 @@ def finalize(fig: Figure, filename: Optional[str] = None):
     do_save = filename and (output_mode == "auto" or output_mode == "file")
     do_show = output_mode == "interactive" or (output_mode == "auto" and not filename)
     if do_show:
-        fig.show()
+        if _is_jupyter():
+            from IPython.display import display
+            display(fig)
+        else:
+            fig.show()
     if do_save:
         filename = file.expand_relative(filename, output_location)
         fig.savefig(filename)
